from typing import Dict, Tuple, Any
from . bfs import BFS
from .bfslib_if import TYPE_BYTE


# -----------------------------------------------------------------------------
#               class iFTS_BFS
# -----------------------------------------------------------------------------
class iFTS_BFS:

    def __init__(self, filename = None):

        self.subfile_variables = None
        self.subfile_params = None
        self.header_params = None
        if filename is not None:
            self.load_file(filename)

    def load_file(self, filename: str):

        bfs = BFS(filename=filename)                                                                    # open the BFS file
        self.header_params = bfs.load_header()                                                          # load in the fixed headers
        self.subfile_variables, self.subfile_params = bfs.load_datafields(loaddata=False)               # load in the variables and subfile header
        datavar = self.subfile_variables['Data']                                                        # get the data interferogram
        if (datavar.bfs_data_type() == TYPE_BYTE):                                                      # if we have BYTE data
            shape = datavar.axes_corder_shape()                                                         # then get the shape of the array in C order
            shape[2] = shape[2] // 2                                                                    # And half  the last dimension
            datavar.set_target_shape(shape)                                                             # set the new target shape
            datavar.set_target_dtype('<u2')                                                             # and flag that we have low endian unsigned 16 bit integers (rather than bytes)

        for key, entry in self.subfile_variables.items():
            entry.load_data()
        bfs.close()

    # -----------------------------------------------------------------------------
    #               __getitem__
    # -----------------------------------------------------------------------------
    def __getitem__(self, name: str):

        value = self.subfile_variables.get(name) if self.subfile_variables is not None else None
        if (value is None):
            value = self.subfile_params.get(name) if self.subfile_params is not None else None
            if (value is None):
                value = self.header_params.get(name) if self.header_params is not None else None
        return value
