from typing import Dict, Tuple, Any
import os.path
import bomem_file_system
import bomem_file_system.bfslib_if as bfsif

# -----------------------------------------------------------------------------
#               test_IFTS_file
# -----------------------------------------------------------------------------
def test_IFTS_file(aname: str):
    basedir,name = os.path.split(__file__)
    filename = os.path.normpath(os.path.join(basedir, "../../../", aname))
    print('Opening ', filename)

    ifts = bomem_file_system.iFTS_BFS(filename)

    for key, value in ifts.header_params.items():
        print("{:s} = [{}]".format(key,value))
    for key, value in ifts.subfile_params.items():
        print("{:s} = [{}]".format(key,value))
    for key, value in ifts.subfile_variables.items():
        print("{:s} = [{}] of shape {} and type {}".format(key, value, value.data.shape, value.data.dtype))
    print('********* FINISHED *************')
    data = ifts['Data'].data[50000,:,:]
    tempir = ifts['IR Elec Temperature']
    int_time = ifts['IntegrationTime']
    print('Done')

def test_file():
    basedir,name = os.path.split(__file__)
    filehandle = bfsif.bfs_open( os.path.join(basedir,"Stream1_Sample_ABS_2008_02_08_16_53_37.spectrum"), "r")
    header  = bfsif.bfs_getHeaderDataBlock(filehandle)
    subfileIndex = 0
    if (subfileIndex < bfsif.bfs_getNumberOfSubfiles(filehandle))and (subfileIndex >= 0):
        bfsif.bfs_readSubfile(filehandle, subfileIndex)
        if (header != -1):
            userid = 0
            timestamp = 0
            v = 1
            status, direction    = bfsif.bfs_readParam(header, "Direction", 0, v)
            stats, spectrumtype  = bfsif.bfs_readParam(header, "SpectrumType", 0, 1)
            status, plus15       = bfsif.bfs_readParam(header, "+15V value", 0, 1)
            status, fpga_version = bfsif.bfs_readParam(header, "FPGA Firmware Version Major", 0, 1)
            status, resolution   = bfsif.bfs_readParam(header, "Resolution", 0, 1)
            status, userid       = bfsif.bfs_readAsciiString(header, "USER_ID", 1500)
            status, timestamp    = bfsif.bfs_readAsciiString(header, "TIMESTAMP", 1500)
            print("Direction-   >{}".format(direction[0]))
            print("SpectrumType->{}".format(spectrumtype[0]))
            print("+15V value  ->{}".format(plus15[0]))
            print("FPGA value  ->{}".format(fpga_version[0]))
            print("Resolution  ->{}".format(resolution[0]))
            print("User ID     ->{}".format(userid))
            print("Timestamp   ->{}".format(timestamp))

            subfile = bfsif.bfs_getSubfileDataBlock(filehandle)

            if (subfileIndex < bfsif.bfs_getNumberOfSubfiles(filehandle)) and (subfileIndex >= 0):
                bfsif.bfs_readSubfile(filehandle, subfileIndex)

                type = bfsif.bfs_readParam(subfile, "Spectrum type", 0, 1)

                deschandle = bfsif.bfs_getDataDescriptor(subfile, "Data")
                if (deschandle):
                    nPts = bfsif.bfs_getAxisNPts(deschandle, 1)
                    status, data = bfsif.bfs_readParam (subfile, "Data", 0,nPts)
                    typeAxis = bfsif.bfs_getAxisType (deschandle, 1)
                    print('Data = ',data)
                    if (typeAxis == bfsif.NO_TYPE):
                        status, axisValue = bfsif.bfs_readAxis (subfile, "Data", 1, 0, nPts)
                        print('axisValue =', axisValue)
                        for i in range(nPts):
                            print ("AXIS={} DATA->{}".format(axisValue[i], data[i]))
    bfsif.bfs_close(filehandle)

test_IFTS_file('i-FTS-CO2-CH4_FILTRE3_1_NoF_ChSp-2019_06_06-15_47_11_260.RawIgm')
test_IFTS_file('0_02_SNR_i-FTS-CO2-CH4_3_1_ChSp-2019_07_03-12_47_34_716.RawIgm')
test_file()
print('Done')



